//===========================================================================
//  @(#) $Name: arts++-1-1-a5 $
//  @(#) $Id: ArtsNextHopTable.cc,v 1.4 1999/04/12 03:21:26 dwm Exp $
//===========================================================================
//  CAIDA Copyright Notice
//
//  By accessing this software, arts++, you are duly informed
//  of and agree to be bound by the conditions described below in this
//  notice:
//
//  This software product, arts++, is developed by Daniel W. McRobb, and
//  copyrighted(C) 1998 by the University of California, San Diego
//  (UCSD), with all rights reserved.  UCSD administers the CAIDA grant,
//  NCR-9711092, under which part of this code was developed.
//
//  There is no charge for arts++ software. You can redistribute it
//  and/or modify it under the terms of the GNU General Public License,
//  v.  2 dated June 1991 which is incorporated by reference herein.
//  arts++ is distributed WITHOUT ANY WARRANTY, IMPLIED OR EXPRESS, OF
//  MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE or that the use
//  of it will not infringe on any third party's intellectual property
//  rights.
//
//  You should have received a copy of the GNU GPL along with arts++.
//  Copies can also be obtained from:
//
//    http://www.gnu.org/copyleft/gpl.html
//
//  or by writing to:
//
//    University of California, San Diego
//
//    SDSC/CAIDA
//    9500 Gilman Dr., MS-0505
//    La Jolla, CA 92093 - 0505  USA
//
//  Or contact:
//
//    info@caida.org
//===========================================================================

#include <string>

#include "Arts.hh"
#include "ArtsNextHopTable.hh"

static const string rcsid = "@(#) $Name: arts++-1-1-a5 $ $Id: ArtsNextHopTable.cc,v 1.4 1999/04/12 03:21:26 dwm Exp $";

//-------------------------------------------------------------------------
//                 ArtsNextHopTable::ArtsNextHopTable()
//.........................................................................
//  
//-------------------------------------------------------------------------
ArtsNextHopTable::ArtsNextHopTable()
{
  this->Header().Identifier(artsC_OBJECT_NEXT_HOP);
  this->_data._nextHopTable = new ArtsNextHopTableData();
}

//-------------------------------------------------------------------------
//                ArtsNextHopTable::~ArtsNextHopTable()
//.........................................................................
//  
//-------------------------------------------------------------------------
ArtsNextHopTable::~ArtsNextHopTable()
{
}

//-------------------------------------------------------------------------
//              uint16_t ArtsNextHopTable::SampleInterval() const             
//.........................................................................
//  
//-------------------------------------------------------------------------
uint16_t ArtsNextHopTable::SampleInterval() const
{
  return(this->_data._nextHopTable->SampleInterval());
}

//-------------------------------------------------------------------------
//   uint16_t ArtsNextHopTable::SampleInterval(uint16_t sampleInterval)     
//.........................................................................
//  
//-------------------------------------------------------------------------
uint16_t ArtsNextHopTable::SampleInterval(uint16_t sampleInterval)
{
  return(this->_data._nextHopTable->SampleInterval(sampleInterval));
}

//-------------------------------------------------------------------------
//             uint64_t ArtsNextHopTable::TotalPkts() const                
//.........................................................................
//  
//-------------------------------------------------------------------------
uint64_t ArtsNextHopTable::TotalPkts() const
{
  return(this->_data._nextHopTable->TotalPkts());
}

//-------------------------------------------------------------------------
//       uint64_t ArtsNextHopTable::TotalPkts(uint64_t totalPkts)          
//.........................................................................
//  
//-------------------------------------------------------------------------
uint64_t ArtsNextHopTable::TotalPkts(uint64_t totalPkts)
{
  return(this->_data._nextHopTable->TotalPkts(totalPkts));
}

//-------------------------------------------------------------------------
//             uint64_t ArtsNextHopTable::TotalBytes() const               
//.........................................................................
//  
//-------------------------------------------------------------------------
uint64_t ArtsNextHopTable::TotalBytes() const
{
  return(this->_data._nextHopTable->TotalBytes());
}

//-------------------------------------------------------------------------
//      uint64_t ArtsNextHopTable::TotalBytes(uint64_t totalBytes)         
//.........................................................................
//  
//-------------------------------------------------------------------------
uint64_t ArtsNextHopTable::TotalBytes(uint64_t totalBytes)
{
  return(this->_data._nextHopTable->TotalBytes(totalBytes));
}

//-------------------------------------------------------------------------
//           vector<ArtsNextHopTableEntry> &
//           ArtsNextHopTable::NextHopEntries() const     
//.........................................................................
//  
//-------------------------------------------------------------------------
vector<ArtsNextHopTableEntry> & ArtsNextHopTable::NextHopEntries() const
{
  return(this->_data._nextHopTable->NextHopEntries());
}

//----------------------------------------------------------------------------
// istream & operator >> (istream & is, ArtsNextHopTable & artsNextHopTable) 
//............................................................................
//  
//----------------------------------------------------------------------------
istream & operator >> (istream & is, ArtsNextHopTable & artsNextHopTable)
{
  streampos   streamPosition;
  ArtsHeader  artsHeader;

  //  save our stream position
  streamPosition = is.tellg();

  //  read the object header
  artsHeader.read(is);
  if (is.eof()) {
    return(is);
  }

  //  skip over objects that are not nexthop table objects
  while (artsHeader.Identifier() != artsC_OBJECT_NEXT_HOP) {
    is.seekg(artsHeader.AttrLength() + artsHeader.DataLength(),ios::cur);
    streamPosition = is.tellg();
    artsHeader.read(is);
    if (is.eof()) {
      break;
    }
  }

  //  if we reached the end of the file before finding a nexthop table
  //  object, just return the istream and don't touch artsNextHopTable
  if (is.eof()) {
    return(is);
  }

  //  back up to the start of the header and read the entire nexthop table
  //  object, then return the istream.
  is.seekg(streamPosition,ios::beg);
  artsNextHopTable.read(is);
  return(is);
}
  
